This project is following this Unix philosophy:  [DOTADIW](https://en.wikipedia.org/wiki/Unix_philosophy#Do_One_Thing_and_Do_It_Well)


____

So the project do a simple task.. validate code meli (Iranian National Code)..thats it..!



the algorithem is explained in Persian in [this site](http://www.aliarash.com/article/codemeli/codemeli.htm)